# RFTG
[![PyPi version](https://pypip.in/v/rftg/badge.png)](https://pypi.org/project/rftg/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/damiencarol/rftg/blob/master/LICENSE)

## Description

AI research project about Race for the Galaxy board game.

## License

[GPLv3](https://www.gnu.org/licenses/gpl-3.0.html)
